#
# advancedPage.py - GUI for advanced options page in
#                   system-config-securitylevel
#
# Chris Lumens  <clumens@redhat.com>
#
# Copyright 2007 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
import gobject, gtk

class AdvancedPage(gobject.GObject):
    __gsignals__ = {
        "check-dirty": (gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, ())
        }

    def __init__(self, xml):
        self.__gobject_init__()
        self.xml = xml
        self.origFilename = None
        self.dirty = False

        # Bring in widgets from glade file.
        self.advancedVBox = self.xml.get_widget("advancedVBox")
        self.customRulesCheckbox = self.xml.get_widget("customRulesCheckbox")
        self.customRulesChooser = self.xml.get_widget("customRulesChooser")
        self.selection_changed_handler = self.customRulesChooser.connect( \
            "selection-changed", self.file_changed)

        # Set up initial sensitivity of things on the advanced page.
        self.customRulesChooser.set_sensitive(False)
        self.custom_changed_handler = self.customRulesCheckbox.connect( \
            "clicked", self.custom_changed_cb)

    def custom_changed_cb(self, button, *args):
        self.customRulesChooser.set_sensitive(button.get_active())
        self.dirty = True
        self.emit("check-dirty")

    def set_active(self, bool):
        self.customRulesCheckbox.handler_block(self.custom_changed_handler)
        self.customRulesCheckbox.set_active(bool)
        self.customRulesCheckbox.handler_unblock(self.custom_changed_handler)

    def set_sensitive(self, bool):
        self.customRulesCheckbox.set_sensitive(bool)

        if self.customRulesCheckbox.get_active():
            self.customRulesChooser.set_sensitive(bool)

    def file_changed(self, *args):
        if self.customRulesChooser.get_filename() != self.origFilename:
            self.dirty = True
            self.emit("check-dirty")

    def set_filename(self, file):
        self.customRulesChooser.handler_block(self.selection_changed_handler)
        self.customRulesChooser.set_filename(file)
        self.customRulesChooser.handler_unblock(self.selection_changed_handler)

    def apply(self):
        if self.customRulesCheckbox.get_active():
            newFilename = self.customRulesChooser.get_filename()
            if newFilename != "":
                return "--custom-rules=%s" % newFilename
        return ""
